@@ -150,42 +150,42 @@ class Atom(BaseRecord):
     always present on each ATOM record; segment identifier and charge are
     optional.
 
-    +---------+--------------+------------+-----------------------------------+
-    | COLUMNS | DATA TYPE    | FIELD      | DEFINITION                        |
-    +=========+==============+============+===================================+
-    | 1-6     | Record name  |  "ATOM  "  |                                   |
-    +---------+--------------+------------+-----------------------------------+
-    | 7-11    | Integer      | serial     | Atom serial number.               |
-    +---------+--------------+------------+-----------------------------------+
-    | 13-16   | Atom         | name       | Atom name.                        |
-    +---------+--------------+------------+-----------------------------------+
-    | 17      | Character    | altLoc     | Alternate location indicator.     |
-    +---------+--------------+------------+-----------------------------------+
-    | 18-20   | Residue name | resName    | Residue name.                     |
-    +---------+--------------+------------+-----------------------------------+
-    | 22      | Character    | chainID    | Chain identifier.                 |
-    +---------+--------------+------------+-----------------------------------+
-    | 23-26   | Integer      | resSeq     | Residue sequence number.          |
-    +---------+--------------+------------+-----------------------------------+
-    | 27      | AChar        | iCode      | Code for insertion of residues.   |
-    +---------+--------------+------------+-----------------------------------+
-    | 31-38   | Real(8.3)    | x          | Orthogonal coordinates for X in   |
-    |         |              |            | Angstroms.                        |
-    +---------+--------------+------------+-----------------------------------+
-    | 39-46   | Real(8.3)    | y          | Orthogonal coordinates for Y in   |
-    |         |              |            | Angstroms.                        |
-    +---------+--------------+------------+-----------------------------------+
-    | 47-54   | Real(8.3)    | z          | Orthogonal coordinates for Z in   |
-    |         |              |            | Angstroms.                        |
-    +---------+--------------+------------+-----------------------------------+
-    | 55-60   | Real(6.2)    | occupancy  | Occupancy.                        |
-    +---------+--------------+------------+-----------------------------------+
-    | 61-66   | Real(6.2)    | tempFactor | Temperature factor.               |
-    +---------+--------------+------------+-----------------------------------+
-    | 77-78   | LString(2)   | element    | Element symbol, right-justified.  |
-    +---------+--------------+------------+-----------------------------------+
-    | 79-80   | LString(2)   | charge     | Charge on the atom.               |
-    +---------+--------------+------------+-----------------------------------+
+    +---------+--------------+-------------+----------------------------------+
+    | COLUMNS | DATA TYPE    | FIELD       | DEFINITION                       |
+    +=========+==============+=============+==================================+
+    | 1-6     | Record name  | "ATOM  "    |                                  |
+    +---------+--------------+-------------+----------------------------------+
+    | 7-11    | Integer      | serial      | Atom serial number.              |
+    +---------+--------------+-------------+----------------------------------+
+    | 13-16   | Atom         | name        | Atom name.                       |
+    +---------+--------------+-------------+----------------------------------+
+    | 17      | Character    | alt_loc     | Alternate location indicator.    |
+    +---------+--------------+-------------+----------------------------------+
+    | 18-20   | Residue name | res_name    | Residue name.                    |
+    +---------+--------------+-------------+----------------------------------+
+    | 22      | Character    | chain_id    | Chain identifier.                |
+    +---------+--------------+-------------+----------------------------------+
+    | 23-26   | Integer      | res_seq     | Residue sequence number.         |
+    +---------+--------------+-------------+----------------------------------+
+    | 27      | AChar        | ins_code    | Code for insertion of residues.  |
+    +---------+--------------+-------------+----------------------------------+
+    | 31-38   | Real(8.3)    | x           | Orthogonal coordinates for X in  |
+    |         |              |             | Angstroms.                       |
+    +---------+--------------+-------------+----------------------------------+
+    | 39-46   | Real(8.3)    | y           | Orthogonal coordinates for Y in  |
+    |         |              |             | Angstroms.                       |
+    +---------+--------------+-------------+----------------------------------+
+    | 47-54   | Real(8.3)    | z           | Orthogonal coordinates for Z in  |
+    |         |              |             | Angstroms.                       |
+    +---------+--------------+-------------+----------------------------------+
+    | 55-60   | Real(6.2)    | occupancy   | Occupancy.                       |
+    +---------+--------------+-------------+----------------------------------+
+    | 61-66   | Real(6.2)    | temp_factor | Temperature factor.              |
+    +---------+--------------+-------------+----------------------------------+
+    | 77-78   | LString(2)   | element     | Element symbol, right-justified. |
+    +---------+--------------+-------------+----------------------------------+
+    | 79-80   | LString(2)   | charge      | Charge on the atom.              |
+    +---------+--------------+-------------+----------------------------------+
     """
 
     def __init__(self):
@@ -255,27 +255,27 @@ class TemperatureFactor(BaseRecord):
     +---------+--------------+----------+-------------------------------------+
     | 13-16   | Atom         | name     | Atom name.                          |
     +---------+--------------+----------+-------------------------------------+
-    | 17      | Character    | altLoc   | Alternate location indicator        |
+    | 17      | Character    | alt_loc  | Alternate location indicator        |
     +---------+--------------+----------+-------------------------------------+
-    | 18-20   | Residue name | resName  | Residue name.                       |
+    | 18-20   | Residue name | res_name | Residue name.                       |
     +---------+--------------+----------+-------------------------------------+
-    | 22      | Character    | chainID  | Chain identifier.                   |
+    | 22      | Character    | chain_id | Chain identifier.                   |
     +---------+--------------+----------+-------------------------------------+
-    | 23-26   | Integer      | resSeq   | Residue sequence number.            |
+    | 23-26   | Integer      | res_seq  | Residue sequence number.            |
     +---------+--------------+----------+-------------------------------------+
-    | 27      | AChar        | iCode    | Insertion code.                     |
+    | 27      | AChar        | ins_code | Insertion code.                     |
     +---------+--------------+----------+-------------------------------------+
-    | 29-35   | Integer      | u[0][0]  | U(1,1)                              |
+    | 29-35   | Integer      | u00      | U(1,1)                              |
     +---------+--------------+----------+-------------------------------------+
-    | 36-42   | Integer      | u[1][1]  | U(2,2)                              |
+    | 36-42   | Integer      | u11      | U(2,2)                              |
     +---------+--------------+----------+-------------------------------------+
-    | 43-49   | Integer      | u[2][2]  | U(3,3)                              |
+    | 43-49   | Integer      | u22      | U(3,3)                              |
     +---------+--------------+----------+-------------------------------------+
-    | 50-56   | Integer      | u[0][1]  | U(1,2)                              |
+    | 50-56   | Integer      | u01      | U(1,2)                              |
     +---------+--------------+----------+-------------------------------------+
-    | 57-63   | Integer      | u[0][2]  | U(1,3)                              |
+    | 57-63   | Integer      | u02      | U(1,3)                              |
     +---------+--------------+----------+-------------------------------------+
-    | 64-70   | Integer      | u[1][2]  | U(2,3)                              |
+    | 64-70   | Integer      | u12      | U(2,3)                              |
     +---------+--------------+----------+-------------------------------------+
     | 77-78   | LString(2)   | element  | Element symbol, right-justified.    |
     +---------+--------------+----------+-------------------------------------+
@@ -348,13 +348,13 @@ class ChainTerminus(BaseRecord):
     +---------+--------------+----------+-------------------------------------+
     | 7-11    | Integer      | serial   | Serial number.                      |
     +---------+--------------+----------+-------------------------------------+
-    | 18-20   | Residue name | resName  | Residue name.                       |
+    | 18-20   | Residue name | res_name | Residue name.                       |
     +---------+--------------+----------+-------------------------------------+
-    | 22      | Character    | chainID  | Chain identifier.                   |
+    | 22      | Character    | chain_id | Chain identifier.                   |
     +---------+--------------+----------+-------------------------------------+
-    | 23-26   | Integer      | resSeq   | Residue sequence number.            |
+    | 23-26   | Integer      | res_seq  | Residue sequence number.            |
     +---------+--------------+----------+-------------------------------------+
-    | 27      | AChar        | iCode    | Insertion code.                     |
+    | 27      | AChar        | ins_code | Insertion code.                     |
     +---------+--------------+----------+-------------------------------------+
     """
 
@@ -397,39 +397,39 @@ class HeterogenAtom(BaseRecord):
     within "non-standard" groups. These records are used for water
     molecules and atoms presented in HET groups.
 
-    +---------+--------------+------------+-----------------------------------+
-    | COLUMNS | DATA TYPE    | FIELD      | DEFINITION                        |
-    +=========+==============+============+===================================+
-    | 1-6     | Record name  | "HETATM"   |                                   |
-    +---------+--------------+------------+-----------------------------------+
-    | 7-11    | Integer      | serial     | Atom serial number.               |
-    +---------+--------------+------------+-----------------------------------+
-    | 13-16   | Atom         | name       | Atom name.                        |
-    +---------+--------------+------------+-----------------------------------+
-    | 17      | Character    | altLoc     | Alternate location indicator.     |
-    +---------+--------------+------------+-----------------------------------+
-    | 18-20   | Residue name | resName    | Residue name.                     |
-    +---------+--------------+------------+-----------------------------------+
-    | 22      | Character    | chainID    | Chain identifier.                 |
-    +---------+--------------+------------+-----------------------------------+
-    | 23-26   | Integer      | resSeq     | Residue sequence number.          |
-    +---------+--------------+------------+-----------------------------------+
-    | 27      | AChar        | iCode      | Code for insertion of residues.   |
-    +---------+--------------+------------+-----------------------------------+
-    | 31-38   | Real(8.3)    | x          | Orthogonal coordinates for X.     |
-    +---------+--------------+------------+-----------------------------------+
-    | 39-46   | Real(8.3)    | y          | Orthogonal coordinates for Y.     |
-    +---------+--------------+------------+-----------------------------------+
-    | 47-54   | Real(8.3)    | z          | Orthogonal coordinates for Z.     |
-    +---------+--------------+------------+-----------------------------------+
-    | 55-60   | Real(6.2)    | occupancy  | Occupancy.                        |
-    +---------+--------------+------------+-----------------------------------+
-    | 61-66   | Real(6.2)    | tempFactor | Temperature factor.               |
-    +---------+--------------+------------+-----------------------------------+
-    | 77-78   | LString(2)   | element    | Element symbol; right-justified.  |
-    +---------+--------------+------------+-----------------------------------+
-    | 79-80   | LString(2)   | charge     | Charge on the atom.               |
-    +---------+--------------+------------+-----------------------------------+
+    +---------+--------------+-------------+----------------------------------+
+    | COLUMNS | DATA TYPE    | FIELD       | DEFINITION                       |
+    +=========+==============+=============+==================================+
+    | 1-6     | Record name  | "HETATM"    |                                  |
+    +---------+--------------+-------------+----------------------------------+
+    | 7-11    | Integer      | serial      | Atom serial number.              |
+    +---------+--------------+-------------+----------------------------------+
+    | 13-16   | Atom         | name        | Atom name.                       |
+    +---------+--------------+-------------+----------------------------------+
+    | 17      | Character    | alt_loc     | Alternate location indicator.    |
+    +---------+--------------+-------------+----------------------------------+
+    | 18-20   | Residue name | res_name    | Residue name.                    |
+    +---------+--------------+-------------+----------------------------------+
+    | 22      | Character    | chain_id    | Chain identifier.                |
+    +---------+--------------+-------------+----------------------------------+
+    | 23-26   | Integer      | res_seq     | Residue sequence number.         |
+    +---------+--------------+-------------+----------------------------------+
+    | 27      | AChar        | ins_code    | Code for insertion of residues.  |
+    +---------+--------------+-------------+----------------------------------+
+    | 31-38   | Real(8.3)    | x           | Orthogonal coordinates for X.    |
+    +---------+--------------+-------------+----------------------------------+
+    | 39-46   | Real(8.3)    | y           | Orthogonal coordinates for Y.    |
+    +---------+--------------+-------------+----------------------------------+
+    | 47-54   | Real(8.3)    | z           | Orthogonal coordinates for Z.    |
+    +---------+--------------+-------------+----------------------------------+
+    | 55-60   | Real(6.2)    | occupancy   | Occupancy.                       |
+    +---------+--------------+-------------+----------------------------------+
+    | 61-66   | Real(6.2)    | temp_factor | Temperature factor.              |
+    +---------+--------------+-------------+----------------------------------+
+    | 77-78   | LString(2)   | element     | Element symbol; right-justified. |
+    +---------+--------------+-------------+----------------------------------+
+    | 79-80   | LString(2)   | charge      | Charge on the atom.              |
+    +---------+--------------+-------------+----------------------------------+
     """
 
     def __init__(self):
